//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[Tile](index.md)/[realNum](real-num.md)

# realNum

[common]\
val [realNum](real-num.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)

真正数字。当num为0时（该牌为红宝牌），realNum为5。其余情况下与num相等。
